@@ -21,7 +21,7 @@ import (
 
 	"k8s.io/klog"
 
-	"github.com/open-cluster-management/multicloud-operators-application/cmd/manager/exec"
+	"github.com/stolostron/multicloud-operators-application/cmd/manager/exec"
 )
 
 func main() {
